==> jc-1.4.0.tar.gz: soot/toolkits/scalar/SimpleLocalDefs.h <==
// public class soot.toolkits.scalar.SimpleLocalDefs

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7bedb47e5e3d72 soot_toolkits_scalar_SimpleLocalDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLocalDefs_H_
#define _JC_soot_toolkits_scalar_SimpleLocalDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs	_jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$refs	_jc_soot_toolkits_scalar_SimpleLocalDefs$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs	_jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object	_jc_soot_toolkits_scalar_SimpleLocalDefs$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods	_jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtable	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLocalDefs$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLocalDefs$method$getDefsOfAt$e4de57a6e143de4b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLocalDefs$method_info$getDefsOfAt$e4de57a6e143de4b;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods {
	struct _jc_object	*(*getDefsOfAt$e4de57a6e143de4b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods	soot_toolkits_scalar_SimpleLocalDefs;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs {
	struct _jc_object	*localUnitPairToDefs;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$refs {
    _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs	soot_toolkits_scalar_SimpleLocalDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs	soot_toolkits_scalar_SimpleLocalDefs;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object {
	_jc_soot_toolkits_scalar_SimpleLocalDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype _jc_soot_toolkits_scalar_SimpleLocalDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLocalDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLocalDefs$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLocalDefs_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/SimpleLocalDefs.h <==
// public class soot.toolkits.scalar.SimpleLocalDefs

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7bedb47e5e3d72 soot_toolkits_scalar_SimpleLocalDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLocalDefs_H_
#define _JC_soot_toolkits_scalar_SimpleLocalDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs	_jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$refs	_jc_soot_toolkits_scalar_SimpleLocalDefs$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs	_jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object	_jc_soot_toolkits_scalar_SimpleLocalDefs$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods	_jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtable	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLocalDefs$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLocalDefs$method$getDefsOfAt$e4de57a6e143de4b(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLocalDefs$method_info$getDefsOfAt$e4de57a6e143de4b;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods {
	struct _jc_object	*(*getDefsOfAt$e4de57a6e143de4b)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vmethods	soot_toolkits_scalar_SimpleLocalDefs;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs {
	struct _jc_object	*localUnitPairToDefs;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$refs {
    _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_refs	soot_toolkits_scalar_SimpleLocalDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLocalDefs$sub_nonrefs	soot_toolkits_scalar_SimpleLocalDefs;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLocalDefs$object {
	_jc_soot_toolkits_scalar_SimpleLocalDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLocalDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLocalDefs$vtype _jc_soot_toolkits_scalar_SimpleLocalDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLocalDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLocalDefs$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLocalDefs_H_ */
